@@ -60,13 +60,16 @@ Globals
 Implementation
 */
 
+/**
+  Constructor
+*/
 MainWindow::MainWindow(QWidget *parent) :
     QMainWindow(parent)
 {
   snprintf(mainButtonStartText,BUFSIZ-1,
            "&Start"
            );
-  this->setupUi();
+  setupUi();
   fsExitButton = new FullScreenExitButton(this);
   fsExitButton->hide();
 
@@ -74,6 +77,9 @@ MainWindow::MainWindow(QWidget *parent) :
   connect(timer, SIGNAL(timeout()), this, SLOT(mainButtonTimeoutUpdate()));
   timerRefreshTimeMs = 100;
 
+  /**
+    Signal connections
+  */
   connect(actionReset, SIGNAL(triggered()), this , SLOT(resetProgram()));
   connect(actionPause, SIGNAL(triggered()), this , SLOT(pauseCounting()));
   connect(actionStartStopMode, SIGNAL(triggered()), this, SLOT(toggleStartStopMode()));
@@ -95,11 +101,15 @@ MainWindow::MainWindow(QWidget *parent) :
 
   connect(this->mainButton, SIGNAL(clicked()), this, SLOT(mainButtonHandler()));
 
+  /**
+    Initial values
+  */
   changeNumberOfLines(8);
   changeFontSize(30);
   isStartStopModeActive = false;
   useDeltaTime = false;
   timeOutput = false;
+  isScreenSaverDisabled = false;
   actionEnable_full_date->setEnabled(false);
   resetProgram();
 #ifdef Q_WS_MAEMO_5
@@ -111,121 +121,17 @@ MainWindow::MainWindow(QWidget *parent) :
   resetUi();
 }
 
+/**
+  Destructor
+*/
 MainWindow::~MainWindow()
 {
   saveFile();
 }
 
-int MainWindow::updateTime()
-{
-  hitCount++;
-  if(1 == hitCount)
-  {
-    overallTime.start();
-  }
-  overallTime.update();
-
-  return EXIT_SUCCESS;
-}
-
-void MainWindow::mainButtonHandler()
-{
-  if(true == isStartStopModeActive)
-  {
-    if(!timer->isActive())
-    {
-      if(hitCount > 1)
-      {
-        pauseCounting();
-      }
-      else
-      {
-        mainButtonRefresh();
-      }
-    }
-    else
-    {
-      mainButtonRefresh();
-      pauseCounting();
-    }
-  }
-  else
-  {
-    mainButtonRefresh();
-  }
-
-  return;
-}
-
-void MainWindow::mainButtonRefresh()
-{
-  updateTime();
-  QString latest = generateHistoryString();
-  QString header = getHeaderLine();
-  QString string = completeString.remove(mainButtonStartText);
-  QStringList lines;
-
-  /* timer handling */
-  if(NULL != timer)
-  {
-    if(1 == hitCount)
-    {
-      timer->start(timerRefreshTimeMs);
-    }
-    else if(hitCount > 1)
-    {
-      if(!timer->isActive())
-      {
-        timer->start(timerRefreshTimeMs);
-      }
-    }
-  }
-
-  mainButtonRefreshTextOnly();
-  if(1 == hitCount)
-  {
-    return;
-  }
-  lines = string.split("\n");
-
-  /* add new entry information directly behind the current header
-       wihtout start information if there is any.
-    */
-  if(lines.length() > 0)
-  {
-    if(lines[0].indexOf("#0") > 0)
-    {
-      lines[0].truncate(lines[0].indexOf("#0"));
-    }
-    lines[0].append(latest);
-  }
-
-  string = lines.join("\n").prepend("\n").prepend(header);
-  completeString = string;
-  lines = string.split("\n");
-  /* adjust the total number of lines of the button */
-  if(lines.length() > maximumNumberOfLines)
-  {
-    while(lines.length() > maximumNumberOfLines
-          && lines.length() > 0)
-    {
-      lines.removeLast();
-    }
-  }
-  else if(lines.length() < maximumNumberOfLines)
-  {
-    while(lines.length() < maximumNumberOfLines)
-    {
-      lines.append(" ");
-    }
-  }
-  string = lines.join("\n");
-  this->mainButton->setText(tr(string.toStdString().c_str()));
-  toggleActionPause();
-#ifdef DEBUG_OUTPUT
-  std::cout << "---" << std::endl << string.toStdString() << std::endl << "-" << string.split("\n").length() << "-" << std::endl;
-#endif
-}
+/*******************************************************************************
+  Private functions
+  *****************************************************************************/
 
 QString MainWindow::generateHistoryString()
 {
@@ -273,6 +179,9 @@ int MainWindow::resetCounters()
   return EXIT_SUCCESS;
 }
 
+/**
+Function to reset ui specific stuff
+*/
 int MainWindow::resetUi()
 {
   this->mainButton->setText(tr(mainButtonStartText));
@@ -283,72 +192,47 @@ int MainWindow::resetUi()
   return EXIT_SUCCESS;
 }
 
-void MainWindow::resetProgram()
-{
-  resetCounters();
-  resetUi();
-  if(timer->isActive())
-  {
-    timer->stop();
-  }
-}
-
-void MainWindow::pauseCounting()
-{
-  toggleTimer();
-  overallTime.pause();
-  toggleActionPause();
-}
-
 int MainWindow::toggleTimer()
 {
-  if(timer->isActive())
+  if(NULL != timer)
   {
-    timer->stop();;
+    if(timer->isActive())
+    {
+      timer->stop();;
+    }
+    else
+    {
+      timer->start(timerRefreshTimeMs);
+    }
+    return EXIT_SUCCESS;
   }
-  else
+  return EXIT_FAILURE;
+}
+
+int MainWindow::updateTime()
+{
+  hitCount++;
+  if(1 == hitCount)
   {
-    timer->start(timerRefreshTimeMs);
+    overallTime.start();
   }
+  overallTime.update();
+
   return EXIT_SUCCESS;
 }
 
-void MainWindow::mainButtonTimeoutUpdate()
+int MainWindow::toggleActionPause()
 {
-  if(!timer->isActive())
+  QString str = this->actionPause->text();
+  if(str == "&Pause" && overallTime.isPaused())
   {
-    assert(0 && "Unintended use");
-    return;
-  }
-  else if(overallTime.isPaused())
-  {
-    timer->stop();
-    return;
-  }
-
-  QString string = this->mainButton->text();
-  QStringList lines = string.split("\n");
-  QString header = getHeaderLine();
-
-  if(lines.length() >= 1)
-  {
-    lines[0] = header;
+    this->actionPause->setText(tr("R&esume"));
   }
   else
   {
-    assert(0 && "Lines are missing");
+    this->actionPause->setText(tr("&Pause"));
   }
-  //update device
-  //update ui
-  this->mainButton->setText(tr(lines.join("\n").toStdString().c_str()));
-
-  //update stored string
-  lines = completeString.split("\n");
-  if(lines.length() >= 1)
-  {
-    lines[0] = header;
-  }
-  completeString = lines.join("\n");
+  return EXIT_SUCCESS;
 }
 
 QString MainWindow::getHeaderLine()
@@ -392,130 +276,9 @@ QString MainWindow::getHeaderLine()
   return headerLine;
 }
 
-void MainWindow::saveToFile()
-{
-  ShowFullListDialog *listHandler;
-  listHandler = new ShowFullListDialog(0,completeString);
-  listHandler->save();
-}
-
-int MainWindow::toggleActionPause()
-{
-  QString str = this->actionPause->text();
-  if(str == "&Pause" && overallTime.isPaused())
-  {
-    this->actionPause->setText(tr("R&esume"));
-  }
-  else
-  {
-    this->actionPause->setText(tr("&Pause"));
-  }
-  return EXIT_SUCCESS;
-}
-
-int MainWindow::updateUiText()
-{
-  toggleActionPause();
-  return EXIT_SUCCESS;
-}
-
-void MainWindow::toggleFullDate()
-{
-  if(overallTime.isDateForStringsEnabled())
-  {
-    overallTime.setDateForStrings(false);
-  }
-  else
-  {
-    overallTime.setDateForStrings(true);
-  }
-}
-
-void MainWindow::toggleTimeDate()
-{
-  if(this->actionEnable_time_and_date->isChecked())
-  {
-    this->actionEnable_full_date->setEnabled(true);
-    timeOutput = true;
-  }
-  else
-  {
-    this->actionEnable_full_date->setDisabled(true);
-    timeOutput = false;
-  }
-}
-
-void MainWindow::about()
-{
-  static AboutDialog *pa = NULL;
-
-  if(NULL == pa)
-  {
-    pa = new AboutDialog;
-    QTextBrowser *examples = new QTextBrowser;
-    examples->setOpenExternalLinks(true);
-    examples->setHtml(
-        "<p><b><a href =\"http://sites.google.com/site/markusscharnowski/n/pushit/real-life-examples\">Examples website with videos and pictures.</a></b></p>"
-        "<p>"
-        "<b>Warning to be read, if the examples are followed:</b><br>"
-        "If this program is used uncautiously you could break your device physically. Always be sure that you use this software and the corresponding hardware in a way that the hardware won't get damaged."
-        "</p>"
-        "<p><b>Excerpt:</b></p>"
-        "<p><b>Pull ups</b></p>"
-        "<p>Place the phone add the position where you are in the highest position, so you can hit it with your nose. In my case I mount the Nokia N900 above a door with the help of some tesa-strips. I also tried it without tesa-strips but after some pushes on the N900 I was too anxious that it could fall down on the floor. So I recommend some safety mechanism to have fun with your device now and in the future. Every time you pulling yourself up, you touch the screen of the N900 with your nose. So you will always know how many pull ups you have done.</p>"
-
-        "<p><b>Push ups</b></p>"
-        "<p>Place the smartphone just below your nose so you can hit it with the nose when in the lowest position. And then start pushing up.</p>"
-
-        "<p><b>Crunches</b></p>"
-        "Doing crunches is a tiny bit more tricky. You have to go into your crunching position (laying on your back, feet up) and place your phone behind your head. Positioned well, you will be able to touch your phone with one of your thumbs every time you are going down (assuming you fold your hands behind your head when doing crunches)."
-
-        "<p><b>Lower back exercise</b></p>"
-        "<p>Place the phone just below your nose so you can hit it with the nose. I don't know how this exercise is called - if you know it, please let me know it too.<br>"
-        "To execute this exercise I lay myself on some pillows on a bench. My legs will get support by a table. The exercise itself is moving you upper body down to the phone and up again till your back is strait like when your are standing on your feet.</p>"
-        );
-
-    QString name = releaseInfo.getPackageNameQ() + " " + releaseInfo.getPackageVersionQ();
-    pa->setProgramName(name);
-    pa->setProgramDate(releaseInfo.getPackageDateQ());
-    pa->setProgramUrl("http://sites.google.com/site/markusscharnowski/n/pushit");
-    pa->tabs->insertTab(5,examples,tr("&Examples"));
-    pa->setMinimumHeight(400);
-    pa->setFeedbackHtmlText(
-        "<p>Do you have ideas for improving the program? You want a specific functionality? "
-        "You have found a bug?</p>"
-        "<p><a href=\"http://code.google.com/p/push-it/issues/list\">Bugtracker</a></p>"
-        "<p>Email <a href=\"mailto:markus.scharnowski@gmail.com?subject=SW Feedback " + windowTitle() +
-        " &body=Hello Markus,\">Feedback</a></p>"
-        );
-  }
-  pa->show();
-}
-
-void MainWindow::showFullList()
-{
-  ShowFullListDialog *ps = new ShowFullListDialog(0,completeString);
-  ps->show();
-}
-
-void MainWindow::showFullScreenHandler()
-{
-  bool isFullScreen = windowState() & Qt::WindowFullScreen;
-  if (isFullScreen)
-  {
-    showNormal();
-  }
-  else
-  {
-    showFullScreen();
-    fsExitButton->show();
-  }
-}
-
-void MainWindow::slotFullscreenExit()
-{
-  action_Fullscreen->trigger();
-}
+/*******************************************************************************
+  Functions for the basic ui setup
+  *****************************************************************************/
 
 void MainWindow::setupUi()
 {
@@ -674,201 +437,10 @@ void MainWindow::retranslateUi()
   menuView->setTitle(QApplication::translate("MainWindow", "&View", 0, QApplication::UnicodeUTF8));
 } // retranslateUi
 
-void MainWindow::changeNumberOfLines(int number)
-{
-  int maxLines = 1000;
-  bool ok = true;
-  if(number == 0)
-  {
-    number = QInputDialog::getInt(this, tr("Lines"),
-                                  tr("Number of lines to be displayed:"),
-                                  maximumNumberOfLines, 0, maxLines, 1,
-                                  &ok);
-  }
 
-  if(false == ok)
-  {
-    return;
-  }
-  else if (number > 0 && number < maxLines)
-  {
-    maximumNumberOfLines = number;
-  }
-  else
-  {
-    QString text;
-    text.sprintf("Invalid entry. Try something like \"4\" (max %i).",maxLines);
-    QMessageBox::information(this, tr("Invalid entry"),
-                             tr(text.toStdString().c_str()));
-    return;
-  }
-
-  QString actionText = actionChangeNumberOfLines->text();
-  actionText = "&Lines (";
-  actionText += QString::number(maximumNumberOfLines);
-  actionText += ")";
-  actionChangeNumberOfLines->setText(actionText);
-  mainButtonRefreshTextOnly();
-}
-
-void MainWindow::changeFontSize(int size)
-{
-  int maxSize = 100;
-  bool ok = false;
-  QFont font = mainButton->font();
-  if(size == 0)
-  {
-    size = QInputDialog::getInt(this, tr("Font size"),
-                                  tr("Font size:"),
-                                  font.pointSize(), 0, maxSize, 1,
-                                  &ok);
-  }
-  else
-  {
-    ok = true;
-  }
-
-  if(false == ok)
-  {
-    return;
-  }
-  else if (size > 0 && size < maxSize)
-  {
-    font.setPointSize(size);
-    mainButton->setFont(font);
-  }
-  else
-  {
-    QString text;
-    text.sprintf("Invalid entry. Try something like \"28\" (max %i).",maxSize);
-    QMessageBox::information(this, tr("Invalid entry"),
-                             tr(text.toStdString().c_str()));
-    return;
-  }
-
-  fontSize = size;
-  QString actionText = actionChangeFontSize->text();
-  actionText = "Font &size (";
-  actionText += QString::number(size);
-  actionText += ")";
-  actionChangeFontSize->setText(actionText);
-  mainButtonRefreshTextOnly();
-}
-
-/*
-function to use when the text itself is not changed but the number of lines or
-the formatting of the text
-*/
-void MainWindow::mainButtonRefreshTextOnly()
-{
-  QString string = completeString;
-  QStringList lines;
-  QString header = getHeaderLine();
-
-  if(0 == hitCount)
-  {
-    return; //nothing to do
-  }
-  else if(1 == hitCount)
-  {
-    string = header;
-  }
-
-  lines = string.split("\n");
-  //only change the first line if it is not the inital string
-  if(string.indexOf("Start") < 0)
-  {
-    if(lines.length() > 0)
-    {
-      lines[0] = header;
-    }
-  }
-
-  /* adjust the total number of lines of the button */
-  if(lines.length() > maximumNumberOfLines)
-  {
-    while(lines.length() > maximumNumberOfLines
-          && lines.length() > 0)
-    {
-      lines.removeLast();
-    }
-  }
-  else if(lines.length() < maximumNumberOfLines)
-  {
-    while(lines.length() < maximumNumberOfLines)
-    {
-      lines.append(" ");
-    }
-  }
-
-  string = lines.join("\n");
-  this->mainButton->setText(tr(string.toStdString().c_str()));
-}
-
-void MainWindow::resetProgramAndFullscreen()
-{
-  resetProgram();
-  action_Fullscreen->trigger();
-}
-
-void MainWindow::toggleStartStopMode()
-{
-  if(true == isStartStopModeActive)
-  {
-    isStartStopModeActive = false;
-  }
-  else
-  {
-    isStartStopModeActive = true;
-  }
-  return;
-}
-
-#ifdef Q_WS_MAEMO_5
-void MainWindow::toggleDisableScreensaver()
-{
-  static bool isDisabled = false;
-#ifdef QT_SCREENSAVER_HANDLING
-  static QtMobility::QSystemScreenSaver *saver = NULL;
-#endif
-
-  if(false == isDisabled)
-  {
-#ifdef MCE_SCREENSAVER_HANDLING
-    QDBusConnection::systemBus().call(QDBusMessage::createMethodCall(MCE_SERVICE, MCE_REQUEST_PATH,
-                                                                     MCE_REQUEST_IF, MCE_PREVENT_BLANK_REQ));
-#endif
-#ifdef QT_SCREENSAVER_HANDLING
-    saver = new QtMobility::QSystemScreenSaver();
-    saver->setScreenSaverInhibit();
-#endif
-    isDisabled = true;
-  }
-  else
-  {
-#ifdef MCE_SCREENSAVER_HANDLING
-    //no idea yet
-#endif
-#ifdef QT_SCREENSAVER_HANDLING
-    saver->deleteLater();
-    saver = NULL;
-#endif
-    isDisabled = false;
-  }
-}
-#endif
-
-void MainWindow::toggleUseDeltaTime()
-{
-  if(true == useDeltaTime)
-  {
-    useDeltaTime = false;
-  }
-  else
-  {
-    useDeltaTime = true;
-  }
-}
+/*******************************************************************************
+  Functions related to loading and saving the config file
+  *****************************************************************************/
 
 int MainWindow::saveFile()
 {
@@ -982,6 +554,10 @@ int MainWindow::getShowFullDateFlag()
 {
   return overallTime.isDateForStringsEnabled();
 }
+int MainWindow::getScreensaverDisabledFlag()
+{
+  return isScreenSaverDisabled;
+}
 
 /*
 Functions to set ui specific behavior flags
@@ -1019,6 +595,15 @@ int MainWindow::setShowFullDateFlag(int n)
   actionEnable_full_date->setChecked(bool(n));
   return bool(n);
 }
+int MainWindow::setScreensaverDisabled(int n)
+{
+#ifdef Q_WS_MAEMO_5
+  isScreenSaverDisabled = !bool(n); //inverted logic for toggle function
+  actionDisableScreensaver->setChecked(bool(n));
+  toggleDisableScreensaver();
+#endif
+  return isScreenSaverDisabled;
+}
 
 MainWindow::StringFunctionMap* MainWindow::getSfm()
 {
@@ -1042,6 +627,9 @@ MainWindow::StringFunctionMap* MainWindow::getSfm()
 {"startPauseMode",
  &MainWindow::getStartPauseFlag,
  &MainWindow::setStartPauseFlag},
+{"disableScreensaver",
+ &MainWindow::getScreensaverDisabledFlag,
+ &MainWindow::setScreensaverDisabled},
 {"",
  NULL,
  NULL}
@@ -1049,3 +637,490 @@ MainWindow::StringFunctionMap* MainWindow::getSfm()
 
   return sfmx;
 }
+
+/*******************************************************************************
+  Functions which are directly related to the main button
+  *****************************************************************************/
+/**
+Function to handle the different modes of the main button
+*/
+void MainWindow::mainButtonHandler()
+{
+  if(true == isStartStopModeActive)
+  {
+    if(!timer->isActive())
+    {
+      if(hitCount > 1)
+      {
+        pauseCounting();
+      }
+      else
+      {
+        mainButtonRefresh();
+      }
+    }
+    else
+    {
+      mainButtonRefresh();
+      pauseCounting();
+    }
+  }
+  else
+  {
+    mainButtonRefresh();
+  }
+
+  return;
+}
+
+void MainWindow::mainButtonRefresh()
+{
+  updateTime();
+  QString latest = generateHistoryString();
+  QString header = getHeaderLine();
+  QString string = completeString.remove(mainButtonStartText);
+  QStringList lines;
+
+  /* timer handling */
+  if(NULL != timer)
+  {
+    if(1 == hitCount)
+    {
+      timer->start(timerRefreshTimeMs);
+    }
+    else if(hitCount > 1)
+    {
+      if(!timer->isActive())
+      {
+        timer->start(timerRefreshTimeMs);
+      }
+    }
+  }
+
+  mainButtonRefreshTextOnly();
+  if(1 == hitCount)
+  {
+    return;
+  }
+  lines = string.split("\n");
+
+  /* add new entry information directly behind the current header
+       wihtout start information if there is any.
+    */
+  if(lines.length() > 0)
+  {
+    if(lines[0].indexOf("#0") > 0)
+    {
+      lines[0].truncate(lines[0].indexOf("#0"));
+    }
+    lines[0].append(latest);
+  }
+
+  string = lines.join("\n").prepend("\n").prepend(header);
+  completeString = string;
+  lines = string.split("\n");
+  /* adjust the total number of lines of the button */
+  if(lines.length() > maximumNumberOfLines)
+  {
+    while(lines.length() > maximumNumberOfLines
+          && lines.length() > 0)
+    {
+      lines.removeLast();
+    }
+  }
+  else if(lines.length() < maximumNumberOfLines)
+  {
+    while(lines.length() < maximumNumberOfLines)
+    {
+      lines.append(" ");
+    }
+  }
+  string = lines.join("\n");
+  this->mainButton->setText(tr(string.toStdString().c_str()));
+  toggleActionPause();
+#ifdef DEBUG_OUTPUT
+  std::cout << "---" << std::endl << string.toStdString() << std::endl << "-" << string.split("\n").length() << "-" << std::endl;
+#endif
+}
+
+/*
+Function to use when the text itself is not changed but the number of lines or
+the formatting of the text
+*/
+void MainWindow::mainButtonRefreshTextOnly()
+{
+  QString string = completeString;
+  QStringList lines;
+  QString header = getHeaderLine();
+
+  if(0 == hitCount)
+  {
+    return; //nothing to do
+  }
+  else if(1 == hitCount)
+  {
+    string = header;
+  }
+
+  lines = string.split("\n");
+  //only change the first line if it is not the inital string
+  if(string.indexOf("Start") < 0)
+  {
+    if(lines.length() > 0)
+    {
+      lines[0] = header;
+    }
+  }
+
+  /* adjust the total number of lines of the button */
+  if(lines.length() > maximumNumberOfLines)
+  {
+    while(lines.length() > maximumNumberOfLines
+          && lines.length() > 0)
+    {
+      lines.removeLast();
+    }
+  }
+  else if(lines.length() < maximumNumberOfLines)
+  {
+    while(lines.length() < maximumNumberOfLines)
+    {
+      lines.append(" ");
+    }
+  }
+
+  string = lines.join("\n");
+  this->mainButton->setText(tr(string.toStdString().c_str()));
+}
+
+void MainWindow::mainButtonTimeoutUpdate()
+{
+  if(NULL != timer)
+  {
+    if(!timer->isActive())
+    {
+      assert(0 && "Unintended use");
+      return;
+    }
+    else if(overallTime.isPaused())
+    {
+      timer->stop();
+      return;
+    }
+  }
+
+  QString string = this->mainButton->text();
+  QStringList lines = string.split("\n");
+  QString header = getHeaderLine();
+
+  if(lines.length() >= 1)
+  {
+    lines[0] = header;
+  }
+  else
+  {
+    assert(0 && "Lines are missing");
+  }
+  //update device
+  //update ui
+  this->mainButton->setText(tr(lines.join("\n").toStdString().c_str()));
+
+  //update stored string
+  lines = completeString.split("\n");
+  if(lines.length() >= 1)
+  {
+    lines[0] = header;
+  }
+  completeString = lines.join("\n");
+}
+
+/*******************************************************************************
+Slot functions (signal receivers)
+*******************************************************************************/
+void MainWindow::pauseCounting()
+{
+  toggleTimer();
+  overallTime.pause();
+  toggleActionPause();
+}
+
+void MainWindow::changeNumberOfLines(int number)
+{
+  int maxLines = 1000;
+  bool ok = true;
+  if(number == 0)
+  {
+    number = QInputDialog::getInt(this, tr("Lines"),
+                                  tr("Number of lines to be displayed:"),
+                                  maximumNumberOfLines, 0, maxLines, 1,
+                                  &ok);
+  }
+
+  if(false == ok)
+  {
+    return;
+  }
+  else if (number > 0 && number < maxLines)
+  {
+    maximumNumberOfLines = number;
+  }
+  else
+  {
+    QString text;
+    text.sprintf("Invalid entry. Try something like \"4\" (max %i).",maxLines);
+    QMessageBox::information(this, tr("Invalid entry"),
+                             tr(text.toStdString().c_str()));
+    return;
+  }
+
+  QString actionText = actionChangeNumberOfLines->text();
+  actionText = "&Lines (";
+  actionText += QString::number(maximumNumberOfLines);
+  actionText += ")";
+  actionChangeNumberOfLines->setText(actionText);
+  mainButtonRefreshTextOnly();
+}
+
+void MainWindow::changeFontSize(int size)
+{
+  int maxSize = 100;
+  bool ok = false;
+  QFont font = mainButton->font();
+  if(size == 0)
+  {
+    size = QInputDialog::getInt(this, tr("Font size"),
+                                  tr("Font size:"),
+                                  font.pointSize(), 0, maxSize, 1,
+                                  &ok);
+  }
+  else
+  {
+    ok = true;
+  }
+
+  if(false == ok)
+  {
+    return;
+  }
+  else if (size > 0 && size < maxSize)
+  {
+    font.setPointSize(size);
+    mainButton->setFont(font);
+  }
+  else
+  {
+    QString text;
+    text.sprintf("Invalid entry. Try something like \"28\" (max %i).",maxSize);
+    QMessageBox::information(this, tr("Invalid entry"),
+                             tr(text.toStdString().c_str()));
+    return;
+  }
+
+  fontSize = size;
+  QString actionText = actionChangeFontSize->text();
+  actionText = "Font &size (";
+  actionText += QString::number(size);
+  actionText += ")";
+  actionChangeFontSize->setText(actionText);
+  mainButtonRefreshTextOnly();
+}
+
+/**
+  Toggle Functions
+*/
+
+void MainWindow::toggleStartStopMode()
+{
+  if(true == isStartStopModeActive)
+  {
+    isStartStopModeActive = false;
+  }
+  else
+  {
+    isStartStopModeActive = true;
+  }
+  return;
+}
+
+void MainWindow::toggleUseDeltaTime()
+{
+  if(true == useDeltaTime)
+  {
+    useDeltaTime = false;
+  }
+  else
+  {
+    useDeltaTime = true;
+  }
+}
+
+void MainWindow::toggleFullDate()
+{
+  if(overallTime.isDateForStringsEnabled())
+  {
+    overallTime.setDateForStrings(false);
+  }
+  else
+  {
+    overallTime.setDateForStrings(true);
+  }
+}
+
+void MainWindow::toggleTimeDate()
+{
+  if(this->actionEnable_time_and_date->isChecked())
+  {
+    this->actionEnable_full_date->setEnabled(true);
+    timeOutput = true;
+  }
+  else
+  {
+    this->actionEnable_full_date->setDisabled(true);
+    timeOutput = false;
+  }
+}
+
+#ifdef Q_WS_MAEMO_5
+void MainWindow::toggleDisableScreensaver()
+{
+#ifdef QT_SCREENSAVER_HANDLING
+  static QtMobility::QSystemScreenSaver *saver = NULL;
+#endif
+
+  if(false == isScreenSaverDisabled)
+  {
+#ifdef MCE_SCREENSAVER_HANDLING
+    QDBusConnection::systemBus().call(QDBusMessage::createMethodCall(MCE_SERVICE, MCE_REQUEST_PATH,
+                                                                     MCE_REQUEST_IF, MCE_PREVENT_BLANK_REQ));
+#endif
+#ifdef QT_SCREENSAVER_HANDLING
+    if(NULL == saver)
+    {
+      saver = new QtMobility::QSystemScreenSaver();
+      saver->setScreenSaverInhibit();
+    }
+#endif
+    isScreenSaverDisabled = true;
+  }
+  else
+  {
+#ifdef MCE_SCREENSAVER_HANDLING
+    //no idea yet
+#endif
+#ifdef QT_SCREENSAVER_HANDLING
+    if(NULL != saver)
+    {
+      saver->deleteLater();
+      saver = NULL;
+    }
+#endif
+    isScreenSaverDisabled = false;
+  }
+}
+#endif
+
+/**
+Function to reset the program to a initial state
+*/
+void MainWindow::resetProgram()
+{
+  resetCounters();
+  resetUi();
+  if(NULL != timer)
+  {
+    if(timer->isActive())
+    {
+      timer->stop();
+    }
+  }
+}
+
+void MainWindow::resetProgramAndFullscreen()
+{
+  resetProgram();
+  action_Fullscreen->trigger();
+}
+
+
+/**
+Function to save generated values to a file directly without viewing
+Currently unused.
+*/
+void MainWindow::saveToFile()
+{
+  ShowFullListDialog *listHandler;
+  listHandler = new ShowFullListDialog(0,completeString);
+  listHandler->save();
+}
+
+void MainWindow::about()
+{
+  static AboutDialog *pa = NULL;
+
+  if(NULL == pa)
+  {
+    pa = new AboutDialog;
+    QTextBrowser *examples = new QTextBrowser;
+    examples->setOpenExternalLinks(true);
+    examples->setHtml(
+        "<p><b><a href =\"http://sites.google.com/site/markusscharnowski/n/pushit/real-life-examples\">Examples website with videos and pictures.</a></b></p>"
+        "<p>"
+        "<b>Warning to be read, if the examples are followed:</b><br>"
+        "If this program is used uncautiously you could break your device physically. Always be sure that you use this software and the corresponding hardware in a way that the hardware won't get damaged."
+        "</p>"
+        "<p><b>Excerpt:</b></p>"
+        "<p><b>Pull ups</b></p>"
+        "<p>Place the phone add the position where you are in the highest position, so you can hit it with your nose. In my case I mount the Nokia N900 above a door with the help of some tesa-strips. I also tried it without tesa-strips but after some pushes on the N900 I was too anxious that it could fall down on the floor. So I recommend some safety mechanism to have fun with your device now and in the future. Every time you pulling yourself up, you touch the screen of the N900 with your nose. So you will always know how many pull ups you have done.</p>"
+
+        "<p><b>Push ups</b></p>"
+        "<p>Place the smartphone just below your nose so you can hit it with the nose when in the lowest position. And then start pushing up.</p>"
+
+        "<p><b>Crunches</b></p>"
+        "Doing crunches is a tiny bit more tricky. You have to go into your crunching position (laying on your back, feet up) and place your phone behind your head. Positioned well, you will be able to touch your phone with one of your thumbs every time you are going down (assuming you fold your hands behind your head when doing crunches)."
+
+        "<p><b>Lower back exercise</b></p>"
+        "<p>Place the phone just below your nose so you can hit it with the nose. I don't know how this exercise is called - if you know it, please let me know it too.<br>"
+        "To execute this exercise I lay myself on some pillows on a bench. My legs will get support by a table. The exercise itself is moving you upper body down to the phone and up again till your back is strait like when your are standing on your feet.</p>"
+        );
+
+    QString name = releaseInfo.getPackageNameQ() + " " + releaseInfo.getPackageVersionQ();
+    pa->setProgramName(name);
+    pa->setProgramDate(releaseInfo.getPackageDateQ());
+    pa->setProgramUrl("http://sites.google.com/site/markusscharnowski/n/pushit");
+    pa->tabs->insertTab(5,examples,tr("&Examples"));
+    pa->setMinimumHeight(400);
+    pa->setFeedbackHtmlText(
+        "<p>Do you have ideas for improving the program? You want a specific functionality? "
+        "You have found a bug?</p>"
+        "<p><a href=\"http://code.google.com/p/push-it/issues/list\">Bugtracker</a></p>"
+        "<p>Email <a href=\"mailto:markus.scharnowski@gmail.com?subject=SW Feedback " + windowTitle() +
+        " &body=Hello Markus,\">Feedback</a></p>"
+        );
+  }
+  pa->show();
+}
+
+void MainWindow::showFullList()
+{
+  ShowFullListDialog *ps = new ShowFullListDialog(0,completeString);
+  ps->show();
+}
+
+void MainWindow::showFullScreenHandler()
+{
+  bool isFullScreen = windowState() & Qt::WindowFullScreen;
+  if (isFullScreen)
+  {
+    showNormal();
+  }
+  else
+  {
+    showFullScreen();
+    fsExitButton->show();
+  }
+}
+
+void MainWindow::slotFullscreenExit()
+{
+  action_Fullscreen->trigger();
+}
